@@ -7,7 +7,7 @@
 # *
 # * This program is free software; you can redistribute it and/or modify
 # * it under the terms of the GNU General Public License as published by
-# * the Free Software Foundation; either version 2 of the License, or
+# * the Free Software Foundation; either version 3 of the License, or
 # * (at your option) any later version.
 # *
 # * This program is distributed in the hope that it will be useful,
@@ -29,7 +29,7 @@ import os
 
 import pyworkflow.utils as pwutils
 from pyworkflow import Config
-from pyworkflow.tests import (BaseTest, setupTestProject, DataSet, setupTestOutput)
+from pyworkflow.tests import BaseTest, setupTestProject, DataSet, setupTestOutput
 from pyworkflow.plugin import Domain
 
 import pwem.objects as emobj
@@ -288,7 +288,6 @@ class TestCryolo(BaseTest):
     def _runPickingTest(self, boxSize, label):
         protcryolo = self.newProtocol(
             protocols.SphireProtCRYOLOPicking,
-            useGenMod=True,
             inputMicrographs=self.protPreprocess.outputMicrographs,
             boxSize=boxSize,
             input_size=750,
@@ -303,7 +302,6 @@ class TestCryolo(BaseTest):
         # No training mode picking
         protcryolo = self.newProtocol(
             protocols.SphireProtCRYOLOPicking,
-            useGenMod=True,
             inputMicrographs=self.protPreprocess.outputMicrographs,
             input_size=750,
             streamingBatchSize=10)
@@ -320,9 +318,8 @@ class TestCryolo(BaseTest):
         try:
             error_msg = protcryolo._validate()
             test_error_msg = ["Input model file '{}' does not exists.".format(model_file_original),
-                              (
-                                      "The general model for cryolo must be downloaded from Sphire website and {} " +
-                                      "must contain the '{}' parameter pointing to the downloaded file.").format(
+                              ("The general model for cryolo must be downloaded from Sphire website and {} " +
+                               "must contain the '{}' parameter pointing to the downloaded file.").format(
                                   Config.SCIPION_LOCAL_CONFIG, CRYOLO_GENMOD_VAR)]
 
             self.assertEqual(error_msg, test_error_msg)
